/*
  Error function of complex numbers.
  Copyright  Marcel Leutenegger, 2003-2008, cole Polytechnique Fdrale de Lausanne (EPFL),
  Laboratoire d'Optique Biomdicale (LOB), BM - Station 17, 1015 Lausanne, Switzerland.

      This library is free software; you can redistribute it and/or modify it under
      the terms of the GNU Lesser General Public License as published by the Free
      Software Foundation; version 2.1 of the License.

      This library is distributed in the hope that it will be useful, but WITHOUT ANY
      WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
      PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

      You should have received a copy of the GNU Lesser General Public License along
      with this library; if not, write to the Free Software Foundation, Inc.,
      51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

/****************************************************************************\
*									     *
*				Error function				     *
*									     *
*									     *
*			Marcel Leutenegger  9.1.2008			     *
*									     *
\****************************************************************************/

#include "mex.h"
#define	O	plhs[0]
#define	S	prhs[0]

void ferfr(double* or, const double* sr, int n);
void ferfz(double* or, double* oi, const double* sr, const double* si, int n);


void mexFunction(int nlhs, mxArray* plhs[], int nrhs, const mxArray* prhs[])
{	int n;
	if (nlhs > 1) mexErrMsgTxt("Too many output arguments.");
	switch(nrhs)
	{default:
		mexErrMsgTxt("Wrong number of input arguments.");
	 case 0:
		mexPrintf("\nError function.\n\n\tMarcel Leutenegger  9.1.2008\n\n");
		break;
	 case 1:
		O=mxCreateDoubleMatrix(0,0,mxREAL);
		mxSetDimensions(O,mxGetDimensions(S),mxGetNumberOfDimensions(S));
		n=mxGetNumberOfElements(S);
		if (n > 0)
		{	double* or=mxMalloc(n*sizeof(double));
			if (mxIsComplex(S))
			{	double* oi=mxMalloc(n*sizeof(double));
				ferfz(or,oi,mxGetPr(S),mxGetPi(S),n);
				mxSetPi(O,oi);
			}
			else	ferfr(or,mxGetPr(S),n);
			mxSetPr(O,or);
		}
	}
}
